# Modbus Protocol for .NET

Implements the Modbus communication protocol as .NET Standard library.

The first shot was made in 2018 - [see on GitHub](https://github.com/AndreasAmMueller/Modbus).
This is the second try with a major UnitTest coverage and some community contributions right from the start.

## Example

You can use the client without any deeper knowledge of the protocol itself.

```cs
string host = "modbus-device.local";
int port = 502;

using var client = new ModbusTcpClient(host, port);
await client.StartAsync(CancellationToken.None);

byte deviceId = 5;
ushort startAddress = 19000;
ushort count = 2;

var registers = await client.ReadHoldingRegistersAsync(deviceId, startAddress, count, CancellationToken.None);
float voltage = registers.GetSingle();

Console.WriteLine($"The voltage between L1 and N is: {voltage:N2}V");
```

For the people who already saw different devices: yes, it's a request to a Janitza device.


## Documentation

The changelog is available here: [CHANGELOG](CHANGELOG.md)    
A documentation can be found here: [AM.WD Wiki](https://wiki.am-wd.de/libs/modbus)


## Sources

- Protocol Specification: [v1.1b3](https://modbus.org/docs/Modbus_Application_Protocol_V1_1b3.pdf)
- Modbus Serial: [v1.02](https://modbus.org/docs/Modbus_over_serial_line_V1_02.pdf)
- Modbus TCP/IP: [v1.0b](https://modbus.org/docs/Modbus_Messaging_Implementation_Guide_V1_0b.pdf)


## Contributors

hmarius, Luke092, maikebing, mishun

_(ordered alphabetically ascending)_

-----

## License

This library is released under the [MIT License](LICENSE.txt)
